<?php
/**
 * CPhpViewRenderer class
 *
 * PHP version 5
 *
 * @category Renderers
 * @package  Ext.renderer
 * @author   Evgeniy Marilev <5soft.jeka@gmail.com>
 */
/**
 * CPhpViewRenderer is the php view renderer class
 * 
 * @category Renderers
 * @package  Ext.renderer
 * @author   Evgeniy Marilev <5soft.jeka@gmail.com>
 */
class CPhpViewRenderer extends CViewRenderer
{
    /**
     * Parses the source view file and saves the results as another file.
     * 
     * @param string $sourceFile the source view file path
     * @param string $viewFile the resulting view file path
     */
    protected function generateViewFile($sourceFile, $viewFile)
    {
        
    }
    
    /**
     * Generates the resulting view file path.
     * 
     * @param string $file source view file path
     * 
     * @return string resulting view file path
     */
    protected function getViewFile($file)
    {
        return $file;
    }
    
    /**
     * Renders a view file.
     * 
     * @param mixed  $context    the controller or widget who is rendering the view file.
     * @param string $sourceFile the view file path
     * @param mixed  $data       the data to be passed to the view
     * @param bool   $return     whether the rendering result should be returned
     * 
     * @return mixed the rendering result, or null if the rendering result is not needed.
     */
    public function renderFile($context, $sourceFile, $data, $return)
    {
        return parent::renderFile($context ? $context : $this, $sourceFile, $data, $return);
    }
    
    /**
     * Renders a view file.
     * 
     * @param string $_viewFile_ view file
     * @param array  $_data_     data to be extracted and made available to the view file
     * @param bool   $_return_   whether the rendering result should be returned as a string
     * 
     * @return string the rendering result. Null if the rendering result is not required.
     */
    public function renderInternal($_viewFile_, $_data_ = null, $_return_ = false)
    {
        if(is_array($_data_)) {
            extract($_data_, EXTR_PREFIX_SAME, 'data');
        } else {
            $data = $_data_;
        }
        if ($_return_) {
            ob_start();
            ob_implicit_flush(false);
            require($_viewFile_);
            return ob_get_clean();
        } else {
            require($_viewFile_);
        }
    }
}